#
# spec file for package python-numcodecs
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-numcodecs
Version:        0.15.1
Release:        1.1
Summary:        Buffer compression and transformation codecs
License:        MIT
URL:            https://github.com/zarr-developers/numcodecs
Source:         https://files.pythonhosted.org/packages/source/n/numcodecs/numcodecs-%{version}.tar.gz
# PATCH-FEATURE-UPSTREAM numcodecs-pr569-systemlibs.patch gh#zarr-developers/numcodecs#569
Patch0:         numcodecs-pr569-systemlibs.patch
# PATCH-FIX-OPENSUSE numcodecs-blosc-snappy-test.patch code@bnavigator.de -- allow testing snappy from the systemlib c-blosc compressors
Patch1:         numcodecs-blosc-snappy-test.patch
BuildRequires:  %{python_module Cython}
BuildRequires:  %{python_module base >= 3.10}
BuildRequires:  %{python_module numpy-devel >= 1.24}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pkgconfig}
BuildRequires:  %{python_module py-cpuinfo}
BuildRequires:  %{python_module setuptools > 64}
BuildRequires:  %{python_module setuptools_scm > 6.2}
BuildRequires:  %{python_module wheel}
BuildRequires:  blosc-devel >= 1.21.5
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
BuildRequires:  python-rpm-macros
BuildRequires:  pkgconfig(liblz4) >= 1.9.3
BuildRequires:  pkgconfig(libzstd) >= 1.5.5
BuildRequires:  pkgconfig(zlib) >= 1.2.13
Requires:       python-deprecated
Requires:       python-numpy >= 1.24
Suggests:       python-msgpack
Suggests:       python-pcodec
Suggests:       (python-zfpy >= 1 with python-numpy < 2)
# SECTION test requirements
BuildRequires:  %{python_module numpy >= 1.24}
BuildRequires:  %{python_module deprecated}
BuildRequires:  %{python_module msgpack}
BuildRequires:  %{python_module pytest}
# /SECTION
%python_subpackages

%description
A Python package providing buffer compression and transformation codecs for use
in data storage and communication applications.

%prep
%autosetup -p1 -n numcodecs-%{version}
# use system libraries instead of bundled ones
rm -r c-blosc
sed -i 's/--cov=numcodecs --cov-report xml//' pyproject.toml
# keep python310 for now. This will fail with the enablement of zarr3 tests
sed -i '/requires-python/ s/3.11/3.10/' pyproject.toml

%build
export CFLAGS="%{optflags}"
export NUMCODECS_USE_SYSTEM_LIBS=1
export DISABLE_NUMCODECS_AVX2=1
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%check
# zarr 3 is not released yet, no crc32c in the distribution yet
# pcodec not in the distribution
%pytest_arch --pyargs numcodecs -rsfE --ignore=%{buildroot}%{$python_sitearch}/numcodecs/{zarr3.py,tests/test_zarr3_import.py,tests/test_checksum32.py,pcodec.py}

%files %{python_files}
%doc README.rst
%license LICENSE.txt
%{python_sitearch}/numcodecs
%{python_sitearch}/numcodecs-%{version}.dist-info

%changelog
* Mon Mar  3 2025 Markéta Machová <mmachova@suse.com>
- Update to 0.15.1
  * Cleanups to the crc32c and pcodec soft dependency.
  * Add support for pcodec 0.3. This exposes the new delta_spec and
    paging_spec arguments, but maintains full backwards compatibility
    for data written with older package versions.
  * Fixes issue with Delta Zarr 3 codec not working with astype.
  * Many blosc funcitons are deprecated, with no replacement.
  * BREAKING: All arguments to the PCodec constructor except for level
    are now keyword only, to support the updated API.
- Drop numcodecs-revert-subtract-pr584.patch
* Wed Nov 20 2024 Ben Greiner <code@bnavigator.de>
- Update to 0.14.0
  [#]# Enhancements
  * Add Crc32c checksum codec. By Norman Rzepka, #613.
  * Add codec wrappers for Zarr 3. By Norman Rzepka, #524
  * Added mypy type checking to continuous integration. By David
    Stansby, #460.
  [#] Fixes
  * Fix in-place mutation of input array in BitRound. By Sam
    Levang, #608
  * Fix an issue where importing numcodecs would lock the state of
    multiprocessing and prevent user code to call
    multiprocessing.set_start_method(“spawn”) subsequently. By
    Clément Robert #522
  [#]# Maintenance
  * The minimum supported Python version is now Python 3.11. By
    David Stansby, #622
  * The minimum supported numpy version is now 1.24. By David
    Stansby, #622
- Release 0.13.1
  [#]# Breaking changes
  * Zstd.default_level, Zstd.min_level, and Zstd.max_level are now
    class methods instead of properties. This means they must now
    be called like Zstd.default_level() instead of
    Zstd.default_level. This breaking change has been made because
    Python 3.13 removes support for class properties. By David
    Stansby, #576.
  [#] Enhancements
  * Update bundled c-blosc to v1.26.1. This updates Zlib to v1.3.1
    and Zstd to v1.5.6. By David Stansby, #560.
  * Added support for Python 3.13 David Stansby, #576.
  * Cleaned up the table of contents in the documentation to list
    codecs by category David Stansby, #458.
  [#]# Maintenance
  * Change format() and old string formatting to f-strings. By
    Dimitri Papadopoulos Orfanos, #439.
  * Remove pin on Sphinx By Elliott Sales de Andrade, #552.
- Refresh numcodecs-pr569-systemlibs.patch
- Keep python310 working (will stop working with zarr 3)
- Add numcodecs-revert-subtract-pr584.patch
  * reverts gh#zarr-developers/numcodecs#584
  * See gh#zarr-developers/numcodecs#653
* Wed Sep 25 2024 Ben Greiner <code@bnavigator.de>
- Update to 0.13.0
  [#]# Enhancements
  * Add checksum flag to zstd and sets the default level to 0. By
    Norman Rzepka, #519.
  * Add PCodec By Ryan Abernathey, #501.
  * Use PyData theme for docs By John Kirkham, #485.
  [#]# Fix
  * Fix VLenUTF8 encoding for read-only buffers. By Isaac Virshup,
    [#514].
  * Fix Upgrade to Zstd 1.5.5 due to potential corruption. By Mark
    Kittisopikul, #429
  * Add version constraint(<2.0) for numpy in zfpy. By Tom Liang,
    [#540].
  [#]# Maintenance
  * The minimum supported Python version is now Python 3.10. By
    David Stansby, #531
  * Add numpy 2 compatibility. By David Stansby, #535
  * Update c-blosc to 1.21.0 to 1.21.5, zstd from 1.4.8 to 1.5.5,
    lz4 from 1.9.3 to 1.9.4, and zlib from 1.2.8 to to 1.2.13 By
    Mark Kittisopikul, #500
- Replace unbundle-libs.patch with numcodecs-pr569-systemlibs.patch
  * gh#zarr-developers/numcodecs#569
- Add numcodecs-blosc-snappy-test.patch so that the test doesn't
  fail from finding the unexpectedly finding the codec in the
  systemlib.
* Fri Mar 29 2024 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Mon Mar 18 2024 Steve Kowalik <steven.kowalik@suse.com>
- Add missing BuildRequires on importlib-metadata for the testsuite.
* Thu Jan 25 2024 Steve Kowalik <steven.kowalik@suse.com>
- Update to 0.12.1:
  * Codec is now derived from abc.ABC By Mads R. B. Kristensen, #472.
  * Fix handling of entry points on older Python versions where
    importlib_metadata compatibility is concerned By Vyas Ramasubramani, #478.
  * Make shuffle pyx functions noexcept By Martin Durant, #477.
  * Add fletcher32 checksum codec By Martin Durant, #410.
  * Add jenkins_lookup3 checksum codec By Mark Kittisopkul, #445.
  * Support Python 3.12. By John Kirkham, #471.
  * Cleanup imports in adhoc/blosc_memleak_check.py By John Kirkham, #408.
- Drop patches move-from-entrypoints.patch,
  numcodecs-pr417-raggednumpy.patch:
  * Included upstream.
* Mon Aug 28 2023 Steve Kowalik <steven.kowalik@suse.com>
- Add patch move-from-entrypoints.patch:
  * Drop requirements on entrypoints, use importlib.metadata.
* Thu Jan 12 2023 Ben Greiner <code@bnavigator.de>
- Update to 0.11.0
  * Speed up isinstance checks of
    numcodecs.ndarray_like.NDArrayLike,
    numcodecs.ndarray_like.DType and
    numcodecs.ndarray_like.FlagsObj. By Andreas Poehlmann, #379.
  * Remove unnecessary None argument to .get(), it is the default
    value. By Dimitri Papadopoulos Orfanos, #395.
  * Apply refurb suggestions. By Dimitri Papadopoulos Orfanos,
    [#372].
  * Migrate codespell configuration to pyproject.toml and get rid
    of setup.cfg. By Dimitri Papadopoulos Orfanos #374.
  * Unvendor cpuinfo. By Dimitri Papadopoulos Orfanos #373.
  * Drop headers. By John Kirkham, #375.
  * Remove Python 2 code. By Dimitri Papadopoulos Orfanos #368,
    [#387].
  * Support Python 3.11. By Dimitri Papadopoulos Orfanos, #369.
  * Drop Python 3.7. By John Kirkham,, #405 #406.
  * Test with zfpy 1.0.0. By John Kirkham, #385.
  * Remove vendored C files and re-generate them on the fly using
    Cython. Add a pyproject.toml file to define Cython as a build
    dependency. By Dimitri Papadopoulos Orfanos, #369.
  * Add tests for all registry classes. By Josh Moore, #349.
  * Finish pyproject.toml migration. By John Kirkham #382.
- Add numcodecs-pr417-raggednumpy.patch
  * gh#zarr-developers/numcodecs#417
- Refresh unbundle-libs.patch for system blosc supporting snappy
  * gh#zarr-developers/numcodecs#264
* Sun Sep 25 2022 Arun Persaud <arun@gmx.de>
- specfile:
  * update copyright year
  * require python >= 3.7
- update to version 0.10.2:
  * Fix
    + Add BitRound (0.10.0) to registry. By Josh Moore, #342.
- changes from version 0.10.1:
  * Maintenance
    + Add entrypoints to setup.py. By Josh Moore, #332.
    + Fix spelling. By Dimitri Papadopoulos Orfanos, #336.
    + Drop Python 3.6 from tests By Dimitri Papadopoulos Orfanos,
    [#338], #339.
    + Remove trailing spaces and empty lines. By Dimitri Papadopoulos
    Orfanos, #341.
    + Add LGTM.com configuration file By Dimitri Papadopoulos Orfanos,
    [#337].
- changes from version 0.10.0:
  * Enhancements
    + Add support of alternative array classes (other than NumPy
    arrays) By Mads R. B. Kristensen, #305.
    + Add ability to find codecs via entrypoint numcodecs.codecs. By
    Martin Durant, #290.
    + Add bitround codec By Ryan Abernathy and Martin Durant, #298.
    + Introduce a flat option to ensure_contiguous_ndarray to switch
    off flatten for ZFPY codec By Haiying Xu, #307.
  * Bug fixes
    + Fix a flatten array error for ZFPY, ZFPY codec is supported on
    Python 3.9 and 3.10 on Linux and MacOS, the docs about ZFPY is
    also available. By Haiying Xu, John Kirkham, Ryan Abernathey
    [#303].
    + Codex: make encode and decode @abstractmethods By Mads
    R. B. Kristensen, #306.
    + Fix expected result test for Shuffle. By Elliott Sales de
    Andrade, #282.
  * Maintenance
    + Multiple code linting fixes. By Dimitri Papadopoulos Orfanos,
    [#295], #294, #293, and #292.
    + Drop Python 3.6 By Josh Moore, #318.
    + Fix macOS Python 3.10 By John Kirkham, #311.
    + chore: bump cibuildwheel version, use action By Henry Schreiner,
    [#309].
    + Specify language as ‘en’ instead of None. By John Kirkham, #329.
    + Move master to main. By John Kirkham, #322.
    + Drop fastparquet benchmark. By John Kirkham, #321.
    + Trim wheel builds. By John Kirkham, #320.
- changes from version 0.9.1:
  * Fix inaccurate docstrings for Blosc. By James Webber, #287.
- changes from version 0.9.0:
  * c-blosc upgrade 1.18.1 -> 1.21.0. Warning: this temporarily
    removes support for snappy compression! By kindjacket, #283.
  * Fix an ImportError with Blosc on Android. By Daniel Jewell, #284.
- changes from version 0.8.1:
  * Fix an ImportError with Blosc on Android. By Daniel Jewell, #284.
- changes from version 0.8.0:
  * The numcodecs.zfpy.ZFPY codec is now supported on Python 3.8 if
    zfpy==0.5.5 is installed. By haiying xu, #229.
  * Add support for byte Shuffle filter By Paul Branson and Martin
    Durant #273.
  * Update Windows + Mac CI to run all tests. By Jackson Maxfield
    Brown, #276. Help from Oleg Höfling, #273.
  * Update cpuinfo to 8.0.0. By Florian Jetter, #280.
  * Drop out-of-date manual release docs. By John Kirkham, #272.
  * Add support for Python 3.9 and Update GitHub Actions.
* Mon Apr 25 2022 Bernhard Wiedemann <bwiedemann@suse.com>
- Disable AVX2 to make package build reproducible (boo#1198818)
* Sat Apr 17 2021 Ben Greiner <code@bnavigator.de>
- Update to v0.7.3
  * Add support for Python 3.9
- Disable python36 build (NumPy not available, NEP 29)
* Mon Dec 28 2020 Benjamin Greiner <code@bnavigator.de>
- initial specfile for v0.7.2
- use and link against system provided blosc, zstd, lz4
  * unbundle-libs.patch
  * gh#zarr-developers/numcodecs#264
- required by zarr, which is required by dask
